==> material-icons-extended-1.1.0-sources.jar: androidx/compose/material/icons/outlined/TimerOff.kt <==
/*
 * Copyright 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.outlined

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.Outlined.TimerOff: ImageVector
    get() {
        if (_timerOff != null) {
            return _timerOff!!
        }
        _timerOff = materialIcon(name = "Outlined.TimerOff") {
            materialPath {
                moveTo(11.0f, 8.0f)
                verticalLineToRelative(0.86f)
                lineToRelative(2.0f, 2.0f)
                lineTo(13.0f, 8.0f)
                close()
                moveTo(9.0f, 1.0f)
                horizontalLineToRelative(6.0f)
                verticalLineToRelative(2.0f)
                lineTo(9.0f, 3.0f)
                close()
                moveTo(12.0f, 6.0f)
                curveToRelative(3.87f, 0.0f, 7.0f, 3.13f, 7.0f, 7.0f)
                curveToRelative(0.0f, 1.12f, -0.27f, 2.18f, -0.74f, 3.12f)
                lineToRelative(1.47f, 1.47f)
                curveTo(20.53f, 16.25f, 21.0f, 14.68f, 21.0f, 13.0f)
                curveToRelative(0.0f, -2.12f, -0.74f, -4.07f, -1.97f, -5.61f)
                lineToRelative(1.42f, -1.42f)
                curveToRelative(-0.43f, -0.51f, -0.9f, -0.99f, -1.41f, -1.41f)
                lineToRelative(-1.42f, 1.42f)
                curveTo(16.07f, 4.74f, 14.12f, 4.0f, 12.0f, 4.0f)
                curveToRelative(-1.68f, 0.0f, -3.25f, 0.47f, -4.59f, 1.27f)
                lineToRelative(1.47f, 1.47f)
                curveToRelative(0.94f, -0.47f, 2.0f, -0.74f, 3.12f, -0.74f)
                close()
                moveTo(3.16f, 3.86f)
                lineTo(1.75f, 5.27f)
                lineTo(4.5f, 8.02f)
                curveTo(3.56f, 9.45f, 3.0f, 11.16f, 3.0f, 13.0f)
                curveToRelative(0.0f, 4.97f, 4.02f, 9.0f, 9.0f, 9.0f)
                curveToRelative(1.84f, 0.0f, 3.55f, -0.55f, 4.98f, -1.5f)
                lineToRelative(2.5f, 2.5f)
                lineToRelative(1.41f, -1.41f)
                lineTo(3.16f, 3.86f)
                close()
                moveTo(12.0f, 20.0f)
                curveToRelative(-3.87f, 0.0f, -7.0f, -3.13f, -7.0f, -7.0f)
                curveToRelative(0.0f, -1.29f, 0.35f, -2.49f, 0.96f, -3.52f)
                lineToRelative(9.57f, 9.57f)
                curveToRelative(-1.04f, 0.6f, -2.24f, 0.95f, -3.53f, 0.95f)
                close()
            }
        }
        return _timerOff!!
    }

private var _timerOff: ImageVector? = null

==> material-icons-extended-1.3.1-sources.jar: androidx/compose/material/icons/outlined/TimerOff.kt <==
/*
 * Copyright 2022 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.outlined

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.ImageVector

public val Icons.Outlined.TimerOff: ImageVector
    get() {
        if (_timerOff != null) {
            return _timerOff!!
        }
        _timerOff = materialIcon(name = "Outlined.TimerOff") {
            materialPath {
                moveTo(9.0f, 1.0f)
                horizontalLineToRelative(6.0f)
                verticalLineToRelative(2.0f)
                horizontalLineToRelative(-6.0f)
                close()
            }
            materialPath {
                moveTo(12.0f, 6.0f)
                curveToRelative(3.87f, 0.0f, 7.0f, 3.13f, 7.0f, 7.0f)
                curveToRelative(0.0f, 0.94f, -0.19f, 1.83f, -0.52f, 2.65f)
                lineToRelative(1.5f, 1.5f)
                curveTo(20.63f, 15.91f, 21.0f, 14.5f, 21.0f, 13.0f)
                curveToRelative(0.0f, -2.12f, -0.74f, -4.07f, -1.97f, -5.61f)
                lineToRelative(1.42f, -1.42f)
                curveToRelative(-0.43f, -0.51f, -0.9f, -0.99f, -1.41f, -1.41f)
                lineToRelative(-1.42f, 1.42f)
                curveTo(16.07f, 4.74f, 14.12f, 4.0f, 12.0f, 4.0f)
                curveToRelative(-1.5f, 0.0f, -2.91f, 0.37f, -4.15f, 1.02f)
                lineToRelative(1.5f, 1.5f)
                curveTo(10.17f, 6.19f, 11.06f, 6.0f, 12.0f, 6.0f)
                close()
            }
            materialPath {
                moveTo(11.0f, 8.17f)
                lineToRelative(2.0f, 2.0f)
                lineToRelative(0.0f, -2.17f)
                lineToRelative(-2.0f, 0.0f)
                close()
            }
            materialPath {
                moveTo(2.81f, 2.81f)
                lineTo(1.39f, 4.22f)
                lineToRelative(3.4f, 3.4f)
                curveTo(3.67f, 9.12f, 3.0f, 10.98f, 3.0f, 13.0f)
                curveToRelative(0.0f, 4.97f, 4.02f, 9.0f, 9.0f, 9.0f)
                curveToRelative(2.02f, 0.0f, 3.88f, -0.67f, 5.38f, -1.79f)
                lineToRelative(2.4f, 2.4f)
                lineToRelative(1.41f, -1.41f)
                lineTo(2.81f, 2.81f)
                close()
                moveTo(12.0f, 20.0f)
                curveToRelative(-3.87f, 0.0f, -7.0f, -3.13f, -7.0f, -7.0f)
                curveToRelative(0.0f, -1.47f, 0.45f, -2.83f, 1.22f, -3.95f)
                lineToRelative(9.73f, 9.73f)
                curveTo(14.83f, 19.55f, 13.47f, 20.0f, 12.0f, 20.0f)
                close()
            }
        }
        return _timerOff!!
    }

private var _timerOff: ImageVector? = null
